@@ -6,7 +6,7 @@ Math::Cartesian::Product - Generate the cartesian product of zero or more lists.
 
  use Math::Cartesian::Product;
 
- cartesian {say "@_"} [qw(a b c)], [1..2];
+ cartesian {print "@_\n"} [qw(a b c)], [1..2];
 
  #  a 1
  #  a 2
@@ -15,6 +15,15 @@ Math::Cartesian::Product - Generate the cartesian product of zero or more lists.
  #  c 1
  #  c 2
 
+ cartesian {print "@_\n"} ([0..1]) x 8;
+
+ #  0 0 0 0 0 0 0 0
+ #  0 0 0 0 0 0 0 1
+ #  0 0 0 0 0 0 1 0
+ #  ...
+ #  1 1 1 1 1 1 1 0
+ #  1 1 1 1 1 1 1 1
+
 =cut
 
 
@@ -88,7 +97,7 @@ use vars qw(@ISA @EXPORT $VERSION);
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw(cartesian);
-$VERSION = '1.003'; # Saturday 21 March 2009
+$VERSION = '1.006'; # Saturday 18 April 2009
 
 =head1 Description
 
@@ -131,9 +140,11 @@ cartesian product produced by an earlier call to C<cartesian()> in the
 set of lists whose cartesian product is to be formed, at the cost of a
 performance penalty if this option is chosen.
 
+  use Math::Cartesian::Product;
+ 
   my $a = [qw(a b)];
-  my $b = [cartesian {} $a, $a;
-  ok 16 == cartesian {} $b, $b;
+  my $b = [cartesian {1} $a, $a];
+  cartesian {print "@_\n"} $b, $b;
 
   # a a a a
   # a a a b       
@@ -181,6 +192,8 @@ http://www.handybackup.com
 
 =item L<Math::Subsets::List>
 
+=item L<Math::Transform::List>
+
 =back
 
 =head1 Copyright
